Unit

Trait Unit 

pub trait Unit:
    Copy
    + PartialEq
    + Debug
    + 'static {
    type Dim: Dimension;

    const RATIO: f64;
    const SYMBOL: &'static str;
}
Trait implemented by every unit type.

  • RATIO is the conversion factor from this unit to the canonical scaling unit of the same dimension. Example: if metres are canonical (Meter::RATIO == 1.0), then kilometres use Kilometer::RATIO == 1000.0 because 1 km = 1000 m.

  • SYMBOL is the printable string (e.g. "m" or "km").

  • Dim ties the unit to its underlying Dimension.

Invariants

  • Implementations should be zero-sized marker types (this crate’s built-in units are unit structs with no fields).
  • RATIO should be finite and non-zero.

Required Associated Constants

const RATIO: f64

Unit-to-canonical conversion factor.

const SYMBOL: &'static str

Printable symbol, shown by core::fmt::Display.

Required Associated Types

type Dim: Dimension

Dimension to which this unit belongs.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Unit for Unitless

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = ""

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Arcminute

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "′"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for Arcsecond

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "″"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for Degree

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = "°"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for Gradian

Source

const RATIO: f64 = 0.9

Source

const SYMBOL: &'static str = "gon"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for HourAngle

Source

const RATIO: f64 = 15.0

Source

const SYMBOL: &'static str = "h"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for MicroArcsecond

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "μas"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for MilliArcsecond

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "mas"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for Milliradian

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "mrad"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for Radian

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "rad"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for Turn

Source

const RATIO: f64 = 360.0

Source

const SYMBOL: &'static str = "turn"

Source

type Dim = Dim<Z0, Z0, Z0, Z0, Z0, Z0, Z0, PInt<UInt<UTerm, B1>>>

Source

impl Unit for Acre

Source

const RATIO: f64 = 4_046.856_422_4

Source

const SYMBOL: &'static str = "ac"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Are

Source

const RATIO: f64 = 100.0

Source

const SYMBOL: &'static str = "a"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Hectare

Source

const RATIO: f64 = 1e4

Source

const SYMBOL: &'static str = "ha"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareCentimeter

Source

const RATIO: f64 = 1e-4

Source

const SYMBOL: &'static str = "cm²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareFoot

Source

const RATIO: f64 = 0.09290304

Source

const SYMBOL: &'static str = "ft²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareInch

Source

const RATIO: f64 = 6.4516e-4

Source

const SYMBOL: &'static str = "in²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareKilometer

Source

const RATIO: f64 = 1e6

Source

const SYMBOL: &'static str = "km²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareMeter

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = "m²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareMile

Source

const RATIO: f64 = 2_589_988.110_336

Source

const SYMBOL: &'static str = "mi²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareMillimeter

Source

const RATIO: f64 = 1e-6

Source

const SYMBOL: &'static str = "mm²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SquareYard

Source

const RATIO: f64 = 0.83612736

Source

const SYMBOL: &'static str = "yd²"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for EarthEquatorialRadius

Source

const RATIO: f64 = 6_378_137.0

Source

const SYMBOL: &'static str = "Rearth_eq"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for EarthPolarRadius

Source

const RATIO: f64 = 6_356_752.314_2

Source

const SYMBOL: &'static str = "Rearth_p"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for EarthRadius

Source

const RATIO: f64 = 6_371_000.0

Source

const SYMBOL: &'static str = "Rearth"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for JupiterRadius

Source

const RATIO: f64 = 71_492_000.0

Source

const SYMBOL: &'static str = "Rjup"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for LunarDistance

Source

const RATIO: f64 = 384_400_000.0

Source

const SYMBOL: &'static str = "LD"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for LunarRadius

Source

const RATIO: f64 = 1_737_400.0

Source

const SYMBOL: &'static str = "Rmoon"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SolarDiameter

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "Dsun"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SolarRadius

Source

const RATIO: f64 = 695_700_000.0

Source

const SYMBOL: &'static str = "Rsun"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for AstronomicalUnit

Source

const RATIO: f64 = 149_597_870_700.0

Source

const SYMBOL: &'static str = "au"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Attometer

Source

const RATIO: f64 = 1e-18

Source

const SYMBOL: &'static str = "am"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for BohrRadius

Source

const RATIO: f64 = 5.291_772_109_03e-11

Source

const SYMBOL: &'static str = "a0"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Centimeter

Source

const RATIO: f64 = 1e-2

Source

const SYMBOL: &'static str = "cm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Chain

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "ch"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for ClassicalElectronRadius

Source

const RATIO: f64 = 2.817_940_326_2e-15

Source

const SYMBOL: &'static str = "re"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decameter

Source

const RATIO: f64 = 1e1

Source

const SYMBOL: &'static str = "dam"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decimeter

Source

const RATIO: f64 = 1e-1

Source

const SYMBOL: &'static str = "dm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for EarthEquatorialCircumference

Source

const RATIO: f64 = 40_075_017.0

Source

const SYMBOL: &'static str = "Ceq"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for EarthMeridionalCircumference

Source

const RATIO: f64 = 40_007_863.0

Source

const SYMBOL: &'static str = "Cmer"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for ElectronReducedComptonWavelength

Source

const RATIO: f64 = 3.861_592_679_6e-13

Source

const SYMBOL: &'static str = "lambda_bar_e"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Exameter

Source

const RATIO: f64 = 1e18

Source

const SYMBOL: &'static str = "Em"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Fathom

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "ftm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Femtometer

Source

const RATIO: f64 = 1e-15

Source

const SYMBOL: &'static str = "fm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Foot

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "ft"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Gigameter

Source

const RATIO: f64 = 1e9

Source

const SYMBOL: &'static str = "Gm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Gigaparsec

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "Gpc"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Hectometer

Source

const RATIO: f64 = 1e2

Source

const SYMBOL: &'static str = "hm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Inch

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "in"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Kilometer

Source

const RATIO: f64 = 1_000.0

Source

const SYMBOL: &'static str = "km"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Kiloparsec

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "kpc"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for LightYear

Source

const RATIO: f64 = METERS_PER_LIGHT_YEAR

Source

const SYMBOL: &'static str = "ly"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "lk"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Megameter

Source

const RATIO: f64 = 1e6

Source

const SYMBOL: &'static str = "Mm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Megaparsec

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "Mpc"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Meter

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = "m"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Micrometer

Source

const RATIO: f64 = 1e-6

Source

const SYMBOL: &'static str = "μm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Mile

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "mi"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Millimeter

Source

const RATIO: f64 = 1e-3

Source

const SYMBOL: &'static str = "mm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Nanometer

Source

const RATIO: f64 = 1e-9

Source

const SYMBOL: &'static str = "nm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for NauticalMile

Source

const RATIO: f64 = 1_852.0

Source

const SYMBOL: &'static str = "nmi"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Parsec

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "pc"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Petameter

Source

const RATIO: f64 = 1e15

Source

const SYMBOL: &'static str = "Pm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Picometer

Source

const RATIO: f64 = 1e-12

Source

const SYMBOL: &'static str = "pm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for PlanckLength

Source

const RATIO: f64 = 1.616_255e-35

Source

const SYMBOL: &'static str = "lp"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Rod

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "rd"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Terameter

Source

const RATIO: f64 = 1e12

Source

const SYMBOL: &'static str = "Tm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Yard

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "yd"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Yoctometer

Source

const RATIO: f64 = 1e-24

Source

const SYMBOL: &'static str = "ym"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Yottameter

Source

const RATIO: f64 = 1e24

Source

const SYMBOL: &'static str = "Ym"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Zeptometer

Source

const RATIO: f64 = 1e-21

Source

const SYMBOL: &'static str = "zm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Zettameter

Source

const RATIO: f64 = 1e21

Source

const SYMBOL: &'static str = "Zm"

Source

type Dim = Dim<PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for AtomicMassUnit

Source

const RATIO: f64 = 1.660_539_068_92e-24

Source

const SYMBOL: &'static str = "u"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Attogram

Source

const RATIO: f64 = 1e-18

Source

const SYMBOL: &'static str = "ag"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Carat

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "ct"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Centigram

Source

const RATIO: f64 = 1e-2

Source

const SYMBOL: &'static str = "cg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decagram

Source

const RATIO: f64 = 1e1

Source

const SYMBOL: &'static str = "dag"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decigram

Source

const RATIO: f64 = 1e-1

Source

const SYMBOL: &'static str = "dg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Exagram

Source

const RATIO: f64 = 1e18

Source

const SYMBOL: &'static str = "Eg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Femtogram

Source

const RATIO: f64 = 1e-15

Source

const SYMBOL: &'static str = "fg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Gigagram

Source

const RATIO: f64 = 1e9

Source

const SYMBOL: &'static str = "Gg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Grain

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "gr"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Gram

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = "g"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Hectogram

Source

const RATIO: f64 = 1e2

Source

const SYMBOL: &'static str = "hg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Kilogram

Source

const RATIO: f64 = 1e3

Source

const SYMBOL: &'static str = "kg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for LongTon

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "ton_uk"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Megagram

Source

const RATIO: f64 = 1e6

Source

const SYMBOL: &'static str = "Mg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Microgram

Source

const RATIO: f64 = 1e-6

Source

const SYMBOL: &'static str = "µg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Milligram

Source

const RATIO: f64 = 1e-3

Source

const SYMBOL: &'static str = "mg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Nanogram

Source

const RATIO: f64 = 1e-9

Source

const SYMBOL: &'static str = "ng"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Ounce

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "oz"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Petagram

Source

const RATIO: f64 = 1e15

Source

const SYMBOL: &'static str = "Pg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Picogram

Source

const RATIO: f64 = 1e-12

Source

const SYMBOL: &'static str = "pg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Pound

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "lb"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for ShortTon

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "ton_us"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SolarMass

Source

const RATIO: f64 = 1.988_416e33

Source

const SYMBOL: &'static str = "M☉"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Stone

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "st"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Teragram

Source

const RATIO: f64 = 1e12

Source

const SYMBOL: &'static str = "Tg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Tonne

Source

const RATIO: f64 = 1_000_000.0

Source

const SYMBOL: &'static str = "t"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Yoctogram

Source

const RATIO: f64 = 1e-24

Source

const SYMBOL: &'static str = "yg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Yottagram

Source

const RATIO: f64 = 1e24

Source

const SYMBOL: &'static str = "Yg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Zeptogram

Source

const RATIO: f64 = 1e-21

Source

const SYMBOL: &'static str = "zg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Zettagram

Source

const RATIO: f64 = 1e21

Source

const SYMBOL: &'static str = "Zg"

Source

type Dim = Dim<Z0, Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Attowatt

Source

const RATIO: f64 = 1e-18

Source

const SYMBOL: &'static str = "aW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decawatt

Source

const RATIO: f64 = 1e1

Source

const SYMBOL: &'static str = "daW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Deciwatt

Source

const RATIO: f64 = 1e-1

Source

const SYMBOL: &'static str = "dW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for ErgPerSecond

Source

const RATIO: f64 = 1e-7

Source

const SYMBOL: &'static str = "erg/s"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Exawatt

Source

const RATIO: f64 = 1e18

Source

const SYMBOL: &'static str = "EW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Femtowatt

Source

const RATIO: f64 = 1e-15

Source

const SYMBOL: &'static str = "fW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Gigawatt

Source

const RATIO: f64 = 1e9

Source

const SYMBOL: &'static str = "GW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Hectowatt

Source

const RATIO: f64 = 1e2

Source

const SYMBOL: &'static str = "hW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for HorsepowerElectric

Source

const RATIO: f64 = 746.0

Source

const SYMBOL: &'static str = "hp_e"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for HorsepowerMetric

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "PS"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Kilowatt

Source

const RATIO: f64 = 1e3

Source

const SYMBOL: &'static str = "kW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Megawatt

Source

const RATIO: f64 = 1e6

Source

const SYMBOL: &'static str = "MW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Microwatt

Source

const RATIO: f64 = 1e-6

Source

const SYMBOL: &'static str = "µW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Milliwatt

Source

const RATIO: f64 = 1e-3

Source

const SYMBOL: &'static str = "mW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Nanowatt

Source

const RATIO: f64 = 1e-9

Source

const SYMBOL: &'static str = "nW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Petawatt

Source

const RATIO: f64 = 1e15

Source

const SYMBOL: &'static str = "PW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Picowatt

Source

const RATIO: f64 = 1e-12

Source

const SYMBOL: &'static str = "pW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SolarLuminosity

Source

const RATIO: f64 = 3.828e26

Source

const SYMBOL: &'static str = "L☉"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Terawatt

Source

const RATIO: f64 = 1e12

Source

const SYMBOL: &'static str = "TW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Watt

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = "W"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Yoctowatt

Source

const RATIO: f64 = 1e-24

Source

const SYMBOL: &'static str = "yW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Yottawatt

Source

const RATIO: f64 = 1e24

Source

const SYMBOL: &'static str = "YW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Zeptowatt

Source

const RATIO: f64 = 1e-21

Source

const SYMBOL: &'static str = "zW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Zettawatt

Source

const RATIO: f64 = 1e21

Source

const SYMBOL: &'static str = "ZW"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B0>>, NInt<UInt<UInt<UTerm, B1>, B1>>, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Attosecond

Source

const RATIO: f64 = 1e-18

Source

const SYMBOL: &'static str = "as"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Centisecond

Source

const RATIO: f64 = 1e-2

Source

const SYMBOL: &'static str = "cs"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Century

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "cent"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Day

Source

const RATIO: f64 = SECONDS_PER_DAY

Source

const SYMBOL: &'static str = "d"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decade

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "dec"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decasecond

Source

const RATIO: f64 = 10.0

Source

const SYMBOL: &'static str = "das"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Decisecond

Source

const RATIO: f64 = 1e-1

Source

const SYMBOL: &'static str = "ds"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Femtosecond

Source

const RATIO: f64 = 1e-15

Source

const SYMBOL: &'static str = "fs"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Fortnight

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "fn"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Gigasecond

Source

const RATIO: f64 = 1e9

Source

const SYMBOL: &'static str = "Gs"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Hectosecond

Source

const RATIO: f64 = 100.0

Source

const SYMBOL: &'static str = "hs"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Hour

Source

const RATIO: f64 = 3_600.0

Source

const SYMBOL: &'static str = "h"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for JulianCentury

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "JC"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for JulianYear

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "a"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Kilosecond

Source

const RATIO: f64 = 1_000.0

Source

const SYMBOL: &'static str = "ks"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Megasecond

Source

const RATIO: f64 = 1e6

Source

const SYMBOL: &'static str = "Ms"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Microsecond

Source

const RATIO: f64 = 1e-6

Source

const SYMBOL: &'static str = "µs"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Millennium

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "mill"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Millisecond

Source

const RATIO: f64 = 1e-3

Source

const SYMBOL: &'static str = "ms"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Minute

Source

const RATIO: f64 = 60.0

Source

const SYMBOL: &'static str = "min"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Nanosecond

Source

const RATIO: f64 = 1e-9

Source

const SYMBOL: &'static str = "ns"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Picosecond

Source

const RATIO: f64 = 1e-12

Source

const SYMBOL: &'static str = "ps"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Second

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = "s"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SiderealDay

Source

const RATIO: f64 = 86_164.090_5

Source

const SYMBOL: &'static str = "sd"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SiderealYear

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "syr"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for SynodicMonth

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "synmo"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Terasecond

Source

const RATIO: f64 = 1e12

Source

const SYMBOL: &'static str = "Ts"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Week

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "wk"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Year

Source

const RATIO: f64

Source

const SYMBOL: &'static str = "yr"

Source

type Dim = Dim<Z0, PInt<UInt<UTerm, B1>>, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Centiliter

Source

const RATIO: f64 = 1e-5

Source

const SYMBOL: &'static str = "cL"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for CubicCentimeter

Source

const RATIO: f64 = 1e-6

Source

const SYMBOL: &'static str = "cm³"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for CubicFoot

Source

const RATIO: f64 = 0.028_316_846_592

Source

const SYMBOL: &'static str = "ft³"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for CubicInch

Source

const RATIO: f64 = 1.638_706_4e-5

Source

const SYMBOL: &'static str = "in³"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for CubicKilometer

Source

const RATIO: f64 = 1e9

Source

const SYMBOL: &'static str = "km³"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for CubicMeter

Source

const RATIO: f64 = 1.0

Source

const SYMBOL: &'static str = "m³"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for CubicMillimeter

Source

const RATIO: f64 = 1e-9

Source

const SYMBOL: &'static str = "mm³"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Deciliter

Source

const RATIO: f64 = 1e-4

Source

const SYMBOL: &'static str = "dL"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Liter

Source

const RATIO: f64 = 1e-3

Source

const SYMBOL: &'static str = "L"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Microliter

Source

const RATIO: f64 = 1e-9

Source

const SYMBOL: &'static str = "µL"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for Milliliter

Source

const RATIO: f64 = 1e-6

Source

const SYMBOL: &'static str = "mL"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for UsFluidOunce

Source

const RATIO: f64 = 2.957_352_956_25e-5

Source

const SYMBOL: &'static str = "fl oz"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl Unit for UsGallon

Source

const RATIO: f64 = 0.003_785_411_784

Source

const SYMBOL: &'static str = "gal"

Source

type Dim = Dim<PInt<UInt<UInt<UTerm, B1>, B1>>, Z0, Z0, Z0, Z0, Z0, Z0, Z0>

Source

impl<A: Unit, B: Unit> Unit for Prod<A, B>
where A::Dim: DimMul<B::Dim>, <A::Dim as DimMul<B::Dim>>::Output: Dimension,

Source

const RATIO: f64

Source

const SYMBOL: &'static str = ""

Source

type Dim = <<A as Unit>::Dim as DimMul<<B as Unit>::Dim>>::Output

Source

impl<N: Unit, D: Unit> Unit for Per<N, D>
where N::Dim: DimDiv<D::Dim>, <N::Dim as DimDiv<D::Dim>>::Output: Dimension,

Source

const RATIO: f64

Source

const SYMBOL: &'static str = ""

Source

type Dim = <<N as Unit>::Dim as DimDiv<<D as Unit>::Dim>>::Output